@@ -1,5 +1,5 @@
 package TestApp::Controller::Root;
-our $VERSION = '0.03.1';
+our $VERSION = '0.01';
 
 
 use Moose;
@@ -40,14 +40,6 @@ sub no_message :Local {
     $c->res->body("No messages");
 }
 
-sub many_messages : Local {
-	my ( $self, $c ) = @_;
-	$c->msg("One");
-	$c->msg("Two");
-	$c->msg("Three");
-	$c->res->body(join ", ", @{$c->stash->{messages}}); 
-}
-
 =head2 end
 
 Attempt to render a view, if needed.
